@@ -1,9 +1,9 @@
 package XTaTIK::Controller::Cart;
 
-our $VERSION = '0.003001'; # VERSION
+our $VERSION = '0.004001'; # VERSION
 
 use Mojo::Base 'Mojolicious::Controller';
-use XTaTIK::Common qw/n_to_br  find_product_pic/;
+use XTaTIK::Common qw/n_to_br  set_product_pic/;
 use experimental 'postderef';
 
 sub index {
@@ -11,7 +11,7 @@ sub index {
 
     my %items = $self->cart->all_items_cart_quote_kv;
     for ( $items{cart}->@*, $items{quote}->@*) {
-        find_product_pic( $self, $_->{image} );
+        set_product_pic( $self, @$_{qw/image number/} );
     }
     $self->stash( %items );
 };
@@ -27,7 +27,7 @@ sub add {
     $self->stash(
         number    => $self->param('number'),
         quantity  => $self->param('quantity'),
-        is_quote  => $p->{price}//0 > 0 ? 0 : 1,
+        is_quote  => $p->{price}//-1 == -1 ? 1 : 0,
         return_to => $self->req->headers->referrer || '/products',
     );
 };
