@@ -1,6 +1,6 @@
 package XTaTIK::Model::Products;
 
-our $VERSION = '0.003001'; # VERSION
+our $VERSION = '0.004001'; # VERSION
 
 use Mojo::Base -base;
 use Mojo::Pg;
@@ -412,10 +412,13 @@ sub _process_products {
         my $pr = $product->{price}->$json->{ $self->site };
         $pr = $pr->{ $region } // $pr->{ '00' }
             if ref $pr;
-        $product->{price} = $pr || '0.00';
+        $product->{price} = $pr // -1;
 
         $product->{contact_for_pricing} = 1
-            unless $product->{price} > 0;
+            if $product->{price} == -1;
+
+        $product->{freebie} = 1
+            if $product->{price} == 0;
 
         $product->{price} = sprintf '%.2f', $product->{price};
         @$product{qw/price_dollars  price_cents/}
@@ -428,8 +431,6 @@ sub _process_products {
         my ( $unit_noun ) = $product->{unit} =~ /(\w+)/;
         $product->{unit_multi} = $product->{unit}
         =~ s/\Q$unit_noun\E/$units{ $unit_noun }/gr;
-
-        $product->{image} //= "$product->{number}.jpg" =~ tr{/}{_}r;
     }
 
     return $data;
