@@ -1,6 +1,6 @@
 package XTaTIK::Plugin::Cart::PayPal;
 
-our $VERSION = '0.003001'; # VERSION
+our $VERSION = '0.004001'; # VERSION
 
 use Mojo::Base 'Mojolicious::Controller';
 use utf8;
@@ -33,10 +33,11 @@ sub _add_routes {
 
 ## ROUTES
 sub thank_you {
-    my ( $self, $c ) = @_;
+    my $self = shift;
 
     return $self->redirect_to('/cart/')
-        unless @{$self->cart->all_items};
+        unless @{$self->cart->all_items}
+            and $self->param('cart_id') eq $self->cart->id;
 
     my $order_num = sprintf $self->xtext('order_number'), $self->cart->id;
     my $quote_num = sprintf $self->xtext('quote_number'), $self->cart->id;
@@ -249,11 +250,13 @@ sub _costs {
         // ($self->session('customer_data') || {})->{province}
     };
 
-    # TODO: are we sure shipping charges get the full tax??
     if ( ref $xtext_tax ) {
         my $hst_rate = $$xtext_tax / 100;
         $hst      = __cur $self->cart->total * $hst_rate;
-        $shipping = __cur $self->xtext('shipping');
+        $shipping = __cur  defined( $self->xtext('shipping_free') )
+            && $self->xtext('shipping_free') < $self->cart->total
+            ? 0 : $self->xtext('shipping');
+
         ( $total_d, $total_c ) = split /\./,
             __cur +($self->cart->total + $shipping) * (1+$hst_rate);
         $shipping *=  1 + $hst_rate;
@@ -263,7 +266,10 @@ sub _costs {
         my $gst_rate = $self->xtext('GST') / 100;
         $gst = __cur $self->cart->total * $gst_rate;
         $pst = __cur $self->cart->total * $pst_rate;
-        $shipping = __cur $self->xtext('shipping');
+        $shipping = __cur  defined( $self->xtext('shipping_free') )
+            && $self->xtext('shipping_free') < $self->cart->total
+            ? 0 : $self->xtext('shipping');
+
         ( $total_d, $total_c ) = split /\./,
             __cur +($self->cart->total + $shipping) * (1+$pst_rate+$gst_rate);
         $shipping *= 1 + $pst_rate + $gst_rate;
