@@ -107,19 +107,34 @@ function setup_index_shoutout() {
                     transform: 'scale(1)'
                 });
 
+                // Center market tag vertically
+                tag.css({'margin-top': 0});
+
+                var logo_height = logo.outerHeight(true);
+
                 // See if we have room to scale up market tag
-                if ( tag.outerHeight() < (end_height/2) ) {
+                if ( tag.outerHeight(true) < (logo_height/2) ) {
                     tag.css({'font-size': '230%'})
                 }
 
-                // Center market tag vertically
-                var pt = ( end_height - tag.outerHeight() )/2
-                    - $('#cart').outerHeight();
+                var tag_height = tag.outerHeight(true)
+                    + $('#cart').outerHeight(true);
 
-                tag.css({
-                    'margin-top': 0,
-                    'padding-top': pt > 0 ? pt : 0
-                });
+                // alert(end_height + '  ' + tag_height );
+                if ( logo_height > tag_height ) {
+                    // logo is larger than tag
+                    tag.css({
+                        'padding-top': ((logo_height-tag_height)/2) + 'px'
+                    });
+                }
+                else {
+                    // tag is larger than logo or same
+                    logo.css({
+                        'margin-top': ((tag_height-logo_height)/2
+                            + 14 // no idea where this value comes from
+                        ) + 'px'
+                    });
+                }
 
                 $('#index_shoutout').animate({opacity: 1}, 500, function(){
                     hot.animate({opacity: 1}, 300, function() {
